@@ -11,7 +11,7 @@
  * maintain one unified version with a ton of #ifdefs didn't seem practical.
  *
  * Originally written by Andrew Mortensen <admorten@umich.edu>
- * Copyirght 2016 Russ Allbery <eagle@eyrie.org>
+ * Copyright 2016, 2020 Russ Allbery <eagle@eyrie.org>
  * Copyright 2008 Andrew Mortensen <admorten@umich.edu>
  * Copyright 2008, 2011-2012, 2014
  *     The Board of Trustees of the Leland Stanford Junior University
@@ -25,8 +25,8 @@
 #include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/types.h>
 #include <time.h>
 
 #include <client/remctl.h>
@@ -36,6 +36,7 @@
 
 static int le_remctl_internal;
 
+/* clang-format off */
 static zend_function_entry remctl_functions[] = {
     ZEND_FE(remctl,               NULL)
     ZEND_FE(remctl_new,           NULL)
@@ -48,9 +49,11 @@ static zend_function_entry remctl_functions[] = {
     ZEND_FE(remctl_output,        NULL)
     ZEND_FE(remctl_noop,          NULL)
     ZEND_FE(remctl_error,         NULL)
-    { NULL, NULL, NULL, 0, 0 }
+    {NULL, NULL, NULL, 0, 0}
 };
+/* clang-format on */
 
+/* clang-format off */
 zend_module_entry remctl_module_entry = {
     STANDARD_MODULE_HEADER,
     PHP_REMCTL_EXTNAME,
@@ -63,11 +66,13 @@ zend_module_entry remctl_module_entry = {
     PHP_REMCTL_VERSION,
     STANDARD_MODULE_PROPERTIES
 };
+/* clang-format on */
 
 #ifdef COMPILE_DL_REMCTL
 ZEND_GET_MODULE(remctl)
 #endif
 
+
 /*
  * Destructor for a remctl object.  Close the underlying connection.
  */
@@ -87,9 +92,8 @@ php_remctl_dtor(zend_rsrc_list_entry *rsrc TSRMLS_DC)
  */
 PHP_MINIT_FUNCTION(remctl)
 {
-    le_remctl_internal =
-        zend_register_list_destructors_ex(php_remctl_dtor, NULL,
-            PHP_REMCTL_RES_NAME, module_number);
+    le_remctl_internal = zend_register_list_destructors_ex(
+        php_remctl_dtor, NULL, PHP_REMCTL_RES_NAME, module_number);
     return SUCCESS;
 }
 
@@ -116,8 +120,9 @@ ZEND_FUNCTION(remctl)
      * validity.  Host and command are required, so all arguments must be
      * provided, but an empty string can be passed in as the principal.
      */
-    status = zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "slsa", &host,
-                 &hlen, &port, &principal, &plen, &cmd_array);
+    status =
+        zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "slsa", &host, &hlen,
+                              &port, &principal, &plen, &cmd_array);
     if (status == FAILURE) {
         zend_error(E_WARNING, "remctl: invalid parameters\n");
         RETURN_NULL();
@@ -188,10 +193,10 @@ ZEND_FUNCTION(remctl)
     else
         add_property_string(return_value, "error", result->error, 1);
     add_property_stringl(return_value, "stdout", result->stdout_buf,
-        result->stdout_len, 1);
+                         result->stdout_len, 1);
     add_property_long(return_value, "stdout_len", result->stdout_len);
     add_property_stringl(return_value, "stderr", result->stderr_buf,
-        result->stderr_len, 1);
+                         result->stderr_len, 1);
     add_property_long(return_value, "stderr_len", result->stderr_len);
     add_property_long(return_value, "status", result->status);
     success = 1;
@@ -236,13 +241,13 @@ ZEND_FUNCTION(remctl_set_ccache)
     int clen, status;
 
     status = zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "rs", &zrem,
-                 &ccache, &clen);
+                                   &ccache, &clen);
     if (status == FAILURE) {
         zend_error(E_WARNING, "remctl_set_ccache: invalid parameters\n");
         RETURN_FALSE;
     }
     ZEND_FETCH_RESOURCE(r, struct remctl *, &zrem, -1, PHP_REMCTL_RES_NAME,
-        le_remctl_internal);
+                        le_remctl_internal);
     if (!remctl_set_ccache(r, ccache))
         RETURN_FALSE;
     RETURN_TRUE;
@@ -260,13 +265,13 @@ ZEND_FUNCTION(remctl_set_source_ip)
     int slen, status;
 
     status = zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "rs", &zrem,
-                 &source, &slen);
+                                   &source, &slen);
     if (status == FAILURE) {
         zend_error(E_WARNING, "remctl_set_source_ip: invalid parameters\n");
         RETURN_FALSE;
     }
     ZEND_FETCH_RESOURCE(r, struct remctl *, &zrem, -1, PHP_REMCTL_RES_NAME,
-        le_remctl_internal);
+                        le_remctl_internal);
     if (!remctl_set_source_ip(r, source))
         RETURN_FALSE;
     RETURN_TRUE;
@@ -284,13 +289,13 @@ ZEND_FUNCTION(remctl_set_timeout)
     int status;
 
     status = zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "rl", &zrem,
-                 &timeout);
+                                   &timeout);
     if (status == FAILURE) {
         zend_error(E_WARNING, "remctl_set_timeout: invalid parameters\n");
         RETURN_FALSE;
     }
     ZEND_FETCH_RESOURCE(r, struct remctl *, &zrem, -1, PHP_REMCTL_RES_NAME,
-        le_remctl_internal);
+                        le_remctl_internal);
     if (!remctl_set_timeout(r, timeout))
         RETURN_FALSE;
     RETURN_TRUE;
@@ -313,7 +318,7 @@ ZEND_FUNCTION(remctl_open)
 
     /* Parse and verify arguments. */
     status = zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "rs|ls", &zrem,
-                 &host, &hlen, &port, &principal, &plen);
+                                   &host, &hlen, &port, &principal, &plen);
     if (status == FAILURE) {
         zend_error(E_WARNING, "remctl_open: invalid parameters\n");
         RETURN_FALSE;
@@ -321,7 +326,7 @@ ZEND_FUNCTION(remctl_open)
     if (plen == 0)
         principal = NULL;
     ZEND_FETCH_RESOURCE(r, struct remctl *, &zrem, -1, PHP_REMCTL_RES_NAME,
-        le_remctl_internal);
+                        le_remctl_internal);
 
     /* Now we have all the arguments and can do the real work. */
     if (!remctl_open(r, host, port, principal))
@@ -346,13 +351,13 @@ ZEND_FUNCTION(remctl_command)
 
     /* Parse and verify arguments. */
     status = zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ra", &zrem,
-                 &cmd_array);
+                                   &cmd_array);
     if (status == FAILURE) {
         zend_error(E_WARNING, "remctl_command: invalid parameters\n");
         RETURN_FALSE;
     }
     ZEND_FETCH_RESOURCE(r, struct remctl *, &zrem, -1, PHP_REMCTL_RES_NAME,
-        le_remctl_internal);
+                        le_remctl_internal);
     hash = Z_ARRVAL_P(cmd_array);
     count = zend_hash_num_elements(hash);
     if (count < 1) {
@@ -376,12 +381,12 @@ ZEND_FUNCTION(remctl_command)
     while (zend_hash_get_current_data_ex(hash, data_ref, &pos) == SUCCESS) {
         if (Z_TYPE_PP(data) != IS_STRING) {
             zend_error(E_WARNING,
-                "remctl_command: command contains non-string\n");
+                       "remctl_command: command contains non-string\n");
             goto cleanup;
         }
         if (i >= count) {
             zend_error(E_WARNING,
-                "remctl_command: internal error: incorrect count\n");
+                       "remctl_command: internal error: incorrect count\n");
             goto cleanup;
         }
         cmd_vec[i].iov_base = emalloc(Z_STRLEN_PP(data) + 1);
@@ -430,7 +435,7 @@ ZEND_FUNCTION(remctl_output)
         RETURN_NULL();
     }
     ZEND_FETCH_RESOURCE(r, struct remctl *, &zrem, -1, PHP_REMCTL_RES_NAME,
-        le_remctl_internal);
+                        le_remctl_internal);
 
     /* Get the output token. */
     output = remctl_output(r);
@@ -449,13 +454,13 @@ ZEND_FUNCTION(remctl_output)
     case REMCTL_OUT_OUTPUT:
         add_property_string(return_value, "type", "output", 1);
         add_property_stringl(return_value, "data", output->data,
-            output->length, 1);
+                             output->length, 1);
         add_property_long(return_value, "stream", output->stream);
         break;
     case REMCTL_OUT_ERROR:
         add_property_string(return_value, "type", "error", 1);
         add_property_stringl(return_value, "data", output->data,
-            output->length, 1);
+                             output->length, 1);
         add_property_long(return_value, "error", output->error);
         break;
     case REMCTL_OUT_STATUS:
@@ -484,7 +489,7 @@ ZEND_FUNCTION(remctl_noop)
         RETURN_FALSE;
     }
     ZEND_FETCH_RESOURCE(r, struct remctl *, &zrem, -1, PHP_REMCTL_RES_NAME,
-        le_remctl_internal);
+                        le_remctl_internal);
     if (!remctl_noop(r))
         RETURN_FALSE;
     RETURN_TRUE;
@@ -508,7 +513,7 @@ ZEND_FUNCTION(remctl_error)
         RETURN_NULL();
     }
     ZEND_FETCH_RESOURCE(r, struct remctl *, &zrem, -1, PHP_REMCTL_RES_NAME,
-        le_remctl_internal);
+                        le_remctl_internal);
 
     /* Do the work. */
     error = remctl_error(r);
@@ -533,7 +538,7 @@ ZEND_FUNCTION(remctl_close)
         RETURN_NULL();
     }
     ZEND_FETCH_RESOURCE(r, struct remctl *, &zrem, -1, PHP_REMCTL_RES_NAME,
-        le_remctl_internal);
+                        le_remctl_internal);
 
     /* This delete invokes php_remctl_dtor, which calls remctl_close. */
     zend_list_delete(Z_LVAL_P(zrem));
