@@ -19,8 +19,8 @@
  */
 
 #include <config.h>
-#include <portable/system.h>
 #include <portable/socket.h>
+#include <portable/system.h>
 
 #include <tests/tap/basic.h>
 
@@ -30,12 +30,12 @@
  * implementation.
  */
 #if AI_NUMERICSERV == 0
-# undef AI_NUMERICSERV
-# define AI_NUMERICSERV 0x0080
+#    undef AI_NUMERICSERV
+#    define AI_NUMERICSERV 0x0080
 #endif
 #if AI_NUMERICHOST == 0
-# undef AI_NUMERICHOST
-# define AI_NUMERICHOST 0x0100
+#    undef AI_NUMERICHOST
+#    define AI_NUMERICHOST 0x0100
 #endif
 
 const char *test_gai_strerror(int);
@@ -105,8 +105,7 @@ main(void)
        "AI_NUMERICSERV with 25 smtp");
     ok(test_getaddrinfo(NULL, "25 ", &hints, &ai) == EAI_NONAME,
        "AI_NUMERICSERV with 25 space");
-    ok(test_getaddrinfo(NULL, "25", &hints, &ai) == 0,
-       "valid AI_NUMERICSERV");
+    ok(test_getaddrinfo(NULL, "25", &hints, &ai) == 0, "valid AI_NUMERICSERV");
     saddr = (struct sockaddr_in *) (void *) ai->ai_addr;
     is_int(htons(25), saddr->sin_port, "...right port");
     is_int(htonl(0x7f000001UL), saddr->sin_addr.s_addr, "...right address");
